@@ -1,5 +1,5 @@
 from PyObjCTools.TestSupport import *
-
+import objc
 import OpenDirectory
 
 try:
@@ -11,6 +11,9 @@ class TestOpenDirectory (TestCase):
     def testConstants(self):
         self.assertIsInstance(OpenDirectory.ODFrameworkErrorDomain, unicode)
 
+    def testProtocols(self):
+        objc.protocolNamed('ODQueryDelegate')
+
 
 if __name__ == "__main__":
     main()
